@@ -3,7 +3,7 @@
 
 # In[1]:
 
-#ver '0.1.15'
+#ver '0.1.19'
 
 get_ipython().run_line_magic('matplotlib', 'inline')
 import matplotlib.pyplot as plt
@@ -16,6 +16,7 @@ from scipy.sparse import identity
 from scipy.sparse import diags
 
 
+
 class fock_space:
     def __init__(self, about_excitations, global_exc, statistics, fermi_sea_modes = None):
 
@@ -67,6 +68,7 @@ class fock_space:
         
         self.local_exc1 = np.array(self.local_exc+1) #internal parameter
         
+        
         #3)
         if statistics == 'Fermi_sea':
             self.states_list = list(self.sea_generator())
@@ -75,6 +77,7 @@ class fock_space:
         
         #4)
         self.find_index = {state: idx for idx, state in enumerate(self.states_list)}
+            
         
         #5)
         self.dimension  = len(self.states_list)
@@ -144,6 +147,8 @@ class fock_space:
                         y = sum(current_state[:k])
                         current_state[k] = 0
                         p = self.index(current_state)
+                        if (p=='666'):
+                            continue
                         row[i] = p
                         data[i]=(-1)**y*(self.states_list[i][k])**0.5
                 A = coo_matrix((data, (row, col)), shape=(self.dimension , self.dimension ), dtype = complex)
@@ -164,6 +169,8 @@ class fock_space:
                         y = sum(current_state[:k])
                         current_state[k] = 1
                         p = self.index(current_state)
+                        if (p=='666'):
+                            continue
                         row[i] = p
                         data[i]=(-1)**y*(self.states_list[i][k]+1)**0.5
                 A = coo_matrix((data, (row, col)), shape=(self.dimension , self.dimension ), dtype = complex)
@@ -173,8 +180,9 @@ class fock_space:
         
         else:
             print('Сhoose the statistics: Bose, Fermi or Fermi_sea')
-                  
-                
+
+             
+    
     def sigmax(self, i):
 
         return(self.annihilate[i] + self.create[i])
@@ -226,7 +234,10 @@ class fock_space:
             print('incorrect size of an array')
         else:
             s = tuple(state)
-            return(self.find_index[s])
+            try:
+                return(self.find_index[s])
+            except:
+                return('666')
     
 
   
@@ -269,7 +280,10 @@ class fock_space:
                 current_state = current_state[:j] + (current_state[j]+1, 0) + current_state[j+2:]
     
     
-    def generator_straight(m,N):
+    
+    def generator_straight(self,m,N):
+        if (m == 0):
+            return
         current_state = (0,)*m
         n = 0
         while True:
@@ -286,7 +300,9 @@ class fock_space:
                 current_state = current_state[:j] + (current_state[j]+1, 0) + current_state[j+2:]
 
                 
-    def generator_back(m,N):
+    def generator_back(self,m,N):
+        if (m == 0):
+            return
         current_state = (0,)*m
         n = 0
         while True:
@@ -307,6 +323,21 @@ class fock_space:
     def sea_generator(self):
         m = self.modes
         m1 = self.fermi_sea_modes
+        if m1==0:
+            current_state = (0,)*len(self.local_exc1)
+            n = 0
+            while True:
+                yield current_state
+                j = len(self.local_exc1) - 1
+                current_state = current_state[:j] + (current_state[j]+1,)
+                n += 1
+                while n > self.global_exc or current_state[j] >= self.local_exc1[j]:
+                    j -= 1
+                    if j < 0:
+                        return
+                    n -= current_state[j+1] - 1
+                    current_state = current_state[:j] + (current_state[j]+1, 0) + current_state[j+2:]
+        
         m2 = m - m1
         N = self.global_exc
         
@@ -315,35 +346,34 @@ class fock_space:
         
         if (N>m1):
             for n1 in range (min(m1,N),-1,-1):
-                for h1 in generator_straight(m1, n1):
+                for h1 in self.generator_straight(m1, n1):
                     yield (h1+h2)
             
             
             for n2 in range (1,min(N-m1,m2)+1):
                     for n1 in range (m1,-1,-1):
-                        for h2 in generator_back(m2, n2):
-                            for h1 in generator_straight(m1, n1):
+                        for h2 in self.generator_back(m2, n2):
+                            for h1 in self.generator_straight(m1, n1):
                                 yield (h1+h2)
             
             if(N-m1<m2):
                 for n2 in range (N-m1+1,N-m1+min(m1,m-N)+1):
                     for n1 in range (N-n2,-1,-1):
-                        for h2 in generator_back(m2, n2):
-                            for h1 in generator_straight(m1, n1):
+                        for h2 in self.generator_back(m2, n2):
+                            for h1 in self.generator_straight(m1, n1):
                                 yield (h1+h2)
         
         else:
             for n1 in range (m1,-1+ m1-N,-1):
-                for h1 in generator_straight(m1, n1):
+                for h1 in self.generator_straight(m1, n1):
                     yield (h1+h2)
                     
             for n2 in range (1,min(m2,N)+1):
                     for n1 in range (N-n2,-1,-1):
-                        for h2 in generator_back(m2, n2):
-                            for h1 in generator_straight(m1, n1):
+                        for h2 in self.generator_back(m2, n2):
+                            for h1 in self.generator_straight(m1, n1):
                                 yield (h1+h2)
-            
-                
+
     
 
 
